Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(956)

Unified Diff: content/browser/frame_host/frame_tree_node.cc

Issue 1723753002: Make Document::isSecureContext() work for OOPIFs (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix WebRemoteFrameImpl assert Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/frame_tree_node.cc
diff --git a/content/browser/frame_host/frame_tree_node.cc b/content/browser/frame_host/frame_tree_node.cc
index 7ef7ca46df61e4cd3d93f61cad43c963a2c4f462..509da71c31ad57797f4ebf7ab3b47427c577c508 100644
--- a/content/browser/frame_host/frame_tree_node.cc
+++ b/content/browser/frame_host/frame_tree_node.cc
@@ -98,7 +98,8 @@ FrameTreeNode::FrameTreeNode(
name,
unique_name,
blink::WebSandboxFlags::None,
- false /* should enforce strict mixed content checking */),
+ false /* should enforce strict mixed content checking */,
+ false /* is a potentially trustworthy unique origin */),
pending_sandbox_flags_(blink::WebSandboxFlags::None),
frame_owner_properties_(frame_owner_properties),
loading_progress_(kLoadingProgressNotStarted) {
@@ -241,6 +242,18 @@ void FrameTreeNode::SetEnforceStrictMixedContentChecking(bool should_enforce) {
should_enforce;
}
+void FrameTreeNode::SetUniqueOriginPotentiallyTrustworthy(
+ bool is_unique_origin_potentially_trustworthy) {
+ if (replication_state_.is_potentially_trustworthy_unique_origin ==
+ is_unique_origin_potentially_trustworthy) {
+ return;
+ }
+ render_manager_.OnSetUniqueOriginPotentiallyTrustworthy(
+ is_unique_origin_potentially_trustworthy);
+ replication_state_.is_potentially_trustworthy_unique_origin =
+ is_unique_origin_potentially_trustworthy;
+}
+
void FrameTreeNode::SetPendingSandboxFlags(
blink::WebSandboxFlags sandbox_flags) {
pending_sandbox_flags_ = sandbox_flags;

Powered by Google App Engine
This is Rietveld 408576698